@@ -1,52 +1,29 @@
 #!/usr/bin/python3
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2021-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2021-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
+
+from __future__ import annotations
 
 import json
 import os
-from collections.abc import Iterator  # noqa: F401
 from contextlib import contextmanager
 from dbm import gnu as gdbm
 from pwd import getpwnam
+from typing import TYPE_CHECKING, Any
 
 from univention.ldap_cache.cache.backend import Caches, LdapCache, Shard, _s
 from univention.ldap_cache.log import debug, log
 
 
+if TYPE_CHECKING:
+    from collections.abc import Iterator
+
+
 MAX_FAIL_COUNT = 5
 
 
 class GdbmCaches(Caches):
-    def _add_sub_cache(self, name, single_value, reverse):
-        # type: (str, bool, bool) -> GdbmCache
+    def _add_sub_cache(self, name: str, single_value: bool, reverse: bool) -> GdbmCache:
         db_file = os.path.join(self._directory, '%s.db' % name)
         debug('Using GDBM %s', name)
         cache = GdbmCache(name, single_value, reverse)
@@ -56,21 +33,18 @@ class GdbmCaches(Caches):
 
 
 class GdbmCache(LdapCache):
-    def __init__(self, *args, **kwargs):
-        # type: (*Any, **Any) -> None
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
         self.fail_count = 0
         super().__init__(*args, **kwargs)
         log('%s - Recreating!', self.name)
 
-    def _fix_permissions(self):
-        # type: () -> None
+    def _fix_permissions(self) -> None:
         listener_uid = getpwnam('listener').pw_uid
         os.chown(self.db_file, listener_uid, -1)
         os.chmod(self.db_file, 0o640)
 
     @contextmanager
-    def writing(self, writer=None):
-        # type: (Optional[Any]) -> Iterator[Any]
+    def writing(self, writer: Any | None = None) -> Iterator[Any]:
         if writer is not None:
             yield writer
         else:
@@ -84,8 +58,7 @@ class GdbmCache(LdapCache):
 
     reading = writing
 
-    def save(self, key, values):
-        # type: (str, List[str]) -> None
+    def save(self, key: str, values: list[str]) -> None:
         with self.writing() as writer:
             if self.reverse:
                 for value in values:
@@ -105,14 +78,12 @@ class GdbmCache(LdapCache):
                 else:
                     writer[key] = json.dumps(values)
 
-    def clear(self):
-        # type: () -> None
+    def clear(self) -> None:
         log('%s - Clearing whole DB!', self.name)
         gdbm.open(self.db_file, 'nu').close()
         self._fix_permissions()
 
-    def cleanup(self):
-        # type: () -> None
+    def cleanup(self) -> None:
         with self.writing() as db:
             try:
                 db.reorganize()
@@ -126,8 +97,7 @@ class GdbmCache(LdapCache):
                 self.fail_count = 0
         self._fix_permissions()
 
-    def delete(self, key, values, writer=None):
-        # type: (str, List[str], Any) -> None
+    def delete(self, key: str, values: list[str], writer: Any = None) -> None:
         debug('%s - Delete %s', self.name, key)
         with self.writing(writer) as writer:
             if self.reverse:
@@ -144,22 +114,19 @@ class GdbmCache(LdapCache):
                 except KeyError:
                     pass
 
-    def keys(self):
-        # type: () -> Iterator[str]
+    def keys(self) -> Iterator[str]:
         with self.reading() as reader:
             key = _s(reader.firstkey())
             while key is not None:
                 yield key
                 key = _s(reader.nextkey(key))
 
-    def __iter__(self):
-        # type: () -> Iterator[Tuple[str, Any]]
+    def __iter__(self) -> Iterator[tuple[str, Any]]:
         with self.reading() as reader:
             for key in self.keys():
                 yield key, self.get(key, reader)
 
-    def get(self, key, reader=None):
-        # type: (str, Any) -> Any
+    def get(self, key: str, reader: Any = None) -> Any:
         with self.reading(reader) as reader:
             try:
                 value = reader[key]
@@ -172,8 +139,7 @@ class GdbmCache(LdapCache):
             elif value:
                 return _s(json.loads(value))
 
-    def load(self):
-        # type: () -> Dict[str, Any]
+    def load(self) -> dict[str, Any]:
         debug('%s - Loading', self.name)
         return dict(list(self))
 
