@@ -1,49 +1,26 @@
 #!/usr/bin/python3
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2021-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2021-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
+
+from __future__ import annotations
 
 import json
-from collections.abc import Iterator  # noqa: F401
 from contextlib import contextmanager
+from typing import TYPE_CHECKING, Any
 
 from univention.ldap_cache.cache import Shard
 from univention.ldap_cache.log import log
 
 
+if TYPE_CHECKING:
+    from collections.abc import Iterator
+
+
 CONFIG_FILE = '/usr/share/univention-group-membership-cache/shards.json'
 
 
-def shards_from_config():
-    # type: () -> List[Type[Shard]]
-    ret = []  # type: List[Type[Shard]]
+def shards_from_config() -> list[type[Shard]]:
+    ret: list[type[Shard]] = []
     try:
         with open(CONFIG_FILE) as fd:
             config = json.load(fd)
@@ -66,8 +43,7 @@ def shards_from_config():
 
 
 @contextmanager
-def _writing_config():
-    # type: () -> Iterator[Any]
+def _writing_config() -> Iterator[Any]:
     try:
         with open(CONFIG_FILE) as fd:
             shards = json.load(fd)
@@ -78,8 +54,7 @@ def _writing_config():
         json.dump(shards, fd, sort_keys=True, indent=4)
 
 
-def add_shard_to_config(db_name, single_value, reverse, key, value, ldap_filter):
-    # type: (str, bool, bool, str, str, str) -> None
+def add_shard_to_config(db_name: str, single_value: bool, reverse: bool, key: str, value: str, ldap_filter: str) -> None:
     with _writing_config() as shards:
         shard_config = {
             'db_name': db_name,
@@ -93,8 +68,7 @@ def add_shard_to_config(db_name, single_value, reverse, key, value, ldap_filter)
             shards.append(shard_config)
 
 
-def rm_shard_from_config(db_name, single_value, reverse, key, value, ldap_filter):
-    # type: (str, bool, bool, str, str, str) -> None
+def rm_shard_from_config(db_name: str, single_value: bool, reverse: bool, key: str, value: str, ldap_filter: str) -> None:
     with _writing_config() as shards:
         try:
             shards.remove({
